==> moodle_1.3.1.orig.tar.gz: moodle/lang/it/glossary.php <==
<?PHP // $Id: glossary.php,v 1.7 2004/05/13 16:01:07 bobopinna Exp $ 
      // glossary.php - created with Moodle 1.3 Beta + (2004051300)


$string['addcomment'] = 'Aggiungi commento';
$string['addentry'] = 'Aggiungi termine';
$string['addingcomment'] = 'Aggiungi un commento';
$string['aliases'] = 'Parole chiave';
$string['allcategories'] = 'Tutte le Categorie';
$string['allentries'] = 'TUTTI';
$string['allowcomments'] = 'Permetti commenti ai termini';
$string['allowduplicatedentries'] = 'Termini duplicati permessi';
$string['allowratings'] = 'Permetti che le definizioni siano valutate?';
$string['answer'] = 'Risposta';
$string['approve'] = 'Approva';
$string['areyousuredelete'] = 'Sei sicuro di voler rimuovere questo termine?';
$string['areyousuredeletecomment'] = 'Sei sicuro di voler cancellare';
$string['areyousureexport'] = 'Sei sicuro di voler esportare questo termine in';
$string['ascending'] = '(crescente)';
$string['attachment'] = 'Allegato';
$string['authorview'] = 'Naviga per Autore';
$string['back'] = 'Indietro';
$string['cantinsertcat'] = 'Non si pu inserire la categoria';
$string['cantinsertrec'] = 'Non si pu inserire il record';
$string['cantinsertrel'] = 'Non si pu inserire la relazione categoria-termine';
$string['casesensitive'] = 'In questo termine importante la capitalizzazione';
$string['categories'] = 'Categorie';
$string['category'] = 'Categoria';
$string['categorydeleted'] = 'Categoria cancellata';
$string['categoryview'] = 'Per Categoria';
$string['cnfallowcomments'] = 'Definsci se un glossario pu accetttare commenti sui termini ';
$string['cnfallowdupentries'] = 'Definisci se un glossario permette la duplicazione di termini';
$string['cnfapprovalstatus'] = 'Definisci lo stato di approvazione di base per un termine spedito da uno studente';
$string['cnfcasesensitive'] = 'Definisci se per un termine, quando  collegato,  importante la capitalizzazione';
$string['cnfdefaulthook'] = 'Seleziona la selezione standard da mostrare quando si accede al glossario la prima volta';
$string['cnfdefaultmode'] = 'Seleziona il segmento standard da mostrare quando si accede al glossario la prima volta';
$string['cnffullmatch'] = 'Definisci se per un termine, quando  collegato, deve corrispondere la capitalizzazione del testo originale';
$string['cnflinkentry'] = 'Definisci se un termine deve essere collegato automaticamente';
$string['cnflinkglossaries'] = 'Definisci se un glossario deve essere collegato automaticamente';
$string['cnfrelatedview'] = 'Seleziona il formato di visualizzazione che deve essere utilizzato per il collegamento automatico e la vista dei termini.';
$string['cnfshowgroup'] = 'Specifica la separazione dei gruppi deve essere mostrata o no.';
$string['cnfsortkey'] = 'Seleziona la chiave di ordinamento standard';
$string['cnfsortorder'] = 'Seleziona il senso di ordinamento standard';
$string['cnfstudentcanpost'] = 'Definisci se lo studente  pu inserire termini o no';
$string['comment'] = 'Commento';
$string['commentdeleted'] = 'Il commento  stato cancellato';
$string['comments'] = 'Commenti';
$string['commentson'] = 'Commenti su';
$string['commentupdated'] = 'Il commento  stato aggiornato';
$string['concept'] = 'Concetto';
$string['concepts'] = 'Concetti';
$string['configenablerssfeeds'] = 'Questa impostazione abilita l\'utilizzo degli RSS per tutti i glossari. E\' comunque necessario abilitarli manualmente nelle impostazioni di ogni glossario.';
$string['currentglossary'] = 'Glossario corrente';
$string['dateview'] = 'Naviga per data';
$string['defaultapproval'] = 'Stato di approvazione standard';
$string['definition'] = 'Definizione';
$string['definitions'] = 'Definizioni';
$string['deleteentry'] = 'Cancella termine';
$string['deletingcomment'] = 'Cancellazione commento';
$string['deletingnoneemptycategory'] = 'Se una categoria non vuota viene cancellata, le relazioni con i suoi termini saranno cancellate. Se vuoi cancellare i termini, dovrai farlo manualmente.';
$string['descending'] = '(decrescente)';
$string['destination'] = 'Destinazione';
$string['displayformat'] = 'Formato di visualizzazione';
$string['displayformat2'] = 'Completo con autore.';
$string['displayformat3'] = 'Enciclopedia.';
$string['displayformat4'] = 'FAQ';
$string['displayformat5'] = 'Completo senza autore';
$string['displayformat6'] = 'Lista termini';
$string['displayformatcontinuous'] = 'Continuo senza autore';
$string['displayformatdefault'] = 'Semplice, stile dizionario';
$string['displayformats'] = 'Formati di visualizzazione';
$string['displayformatssetup'] = 'Impostazione del formato di visualizzazione';
$string['duplicateentry'] = 'Termine duplicato';
$string['editcategories'] = 'Modifica categorie';
$string['editentry'] = 'Modifica termine';
$string['editingcomment'] = 'Modifica commento';
$string['entbypage'] = 'Termini mostrati per pagina';
$string['entries'] = 'Termini';
$string['entrieswithoutcategory'] = 'Termini senza categorie';
$string['entry'] = 'Termine';
$string['entryalreadyexist'] = 'Il termine esiste gi';
$string['entryapproved'] = 'Questo termine  stato approvato';
$string['entrydeleted'] = 'Termine cancellato.';
$string['entryexported'] = 'Termine esportato correttamente.';
$string['entryishidden'] = '(questo termine  attualmente nascosto)';
$string['entryleveldefaultsettings'] = 'Impostazione del livello di ingresso standard';
$string['entryusedynalink'] = 'Questo termine deve essere collegato automaticamente';
$string['explainaddentry'] = 'Aggiungi un nuovo termine al glossario corrente.<br />Concetto e definizione sono campi necessari.';
$string['explainall'] = '<b>TUTTI</b> mostrer tutti i termini in una pagina.';
$string['explainalphabet'] = 'Seleziona la lettera che vuoi vedere.<br><br>';
$string['explainexport'] = 'Un file  stato creato.<br />Scaricalo e mettilo al sicuro. Lo potrai importare quando vorrai in questo o in un altro corso.';
$string['explainimport'] = 'Devi specificare il file da importare e definire il criterio per elaborarlo. <br />Sottoponi la tua richiesta ';
$string['explainspecial'] = '<b>Speciali</b> mostrer tutti i termini che non iniziano con una lettera.';
$string['exportedentry'] = 'Termine esportato';
$string['exportedfile'] = 'File esportato';
$string['exportentries'] = 'Esporta termini';
$string['exportglossary'] = 'Esporta glossario';
$string['exporttomainglossary'] = 'Esporta nel glossario generale';
$string['filetoimport'] = 'File da importare';
$string['fillfields'] = 'Concetto e definizione sono campi necessari.';
$string['filtername'] = 'Auto-collegamento al glossario';
$string['fullmatch'] = 'Trova tutte le parole solo<br /><small>(quando collegato automaticamente)</small>';
$string['glossaryleveldefaultsettings'] = 'Impostazione del livello dei glossari standard';
$string['glossarytype'] = 'Tipo di Glossario';
$string['glosssaryexported'] = 'Glossario esportato';
$string['importcategories'] = 'Importa categorie';
$string['importedcategories'] = 'Categorie importate';
$string['importedentries'] = 'Termini importati';
$string['importentries'] = 'Importa termini';
$string['isglobal'] = 'Questo glossario  globale?';
$string['linkcategory'] = 'Collega automaticamente questa categoria';
$string['mainglossary'] = 'Glossario generale';
$string['maxtimehaspassed'] = 'Spiacente, ma il tempo massimo per modificare questo commento ($a)  terminato!';
$string['modulename'] = 'Glossario';
$string['modulenameplural'] = 'Glossari';
$string['newentries'] = 'Nuovi termini del glossario';
$string['newglossary'] = 'Nuovo glossario';
$string['newglossarycreated'] = 'Creato nuovo glossario.';
$string['newglossaryentries'] = 'Nuovo termine del glossario:';
$string['nocomment'] = 'Nessun commento trovato';
$string['nocomments'] = '(Nessun commento trovato per questo termine)';
$string['noconceptfound'] = 'Nessun concetto o definizione trovato.';
$string['noentries'] = 'Nessun termine trovato in questa sessione';
$string['noentry'] = 'Nessun termine trovato.';
$string['notcategorised'] = 'Non diviso in categorie';
$string['numberofentries'] = 'Numeto di termini';
$string['onebyline'] = '(uno per riga)';
$string['printerfriendly'] = 'Versione stampabile';
$string['question'] = 'Domanda';
$string['rate'] = 'Voto';
$string['rating'] = 'Valutazione';
$string['ratingeveryone'] = 'Tutti possono valutare i termini';
$string['ratingno'] = 'Nessuna valutazione';
$string['ratingonlyteachers'] = 'Solo $a pu valutare i termini';
$string['ratings'] = 'Valutazioni';
$string['ratingssaved'] = 'Valutazioni salvate';
$string['ratingsuse'] = 'Utilizza le valutazioni';
$string['ratingtime'] = 'Restringi la valutazione ai termini tra queste date:';
$string['rejectedentries'] = 'Termini rigettati';
$string['rejectionrpt'] = 'Rapporto rigettazione';
$string['rsssubscriberss'] = 'Mostra gli RSS per \'$a\' concetti.';
$string['searchindefinition'] = 'Cerco tra i concetti e le definizioni?';
$string['secondaryglossary'] = 'Glossario secondario';
$string['sendinratings'] = 'Spediscilo nella mia ultima valutazione';
$string['showall'] = 'Mostra link \'TUTTI\'';
$string['showalphabet'] = 'Mostra alfabeto';
$string['showspecial'] = 'Mostra link \'Speciali\'';
$string['sortby'] = 'Ordina per ';
$string['sortbycreation'] = 'Per data di creazione';
$string['sortbylastupdate'] = 'Per ultimo aggiornamento';
$string['sortchronogically'] = 'Ordina cronologicamente';
$string['special'] = 'Speciali';
$string['standardview'] = 'Vista Standard';
$string['studentcanpost'] = 'Gli studenti posso aggiungere termini';
$string['totalentries'] = 'Totale termini';
$string['usedynalink'] = 'Collega automaticamente i termini del glossario';
$string['waitingapproval'] = 'Attede approvazione';
$string['warningstudentcapost'] = '(Questo viene applicato solo se il glossario non  quello generale)';
$string['withauthor'] = 'Concetto con autore';
$string['withoutauthor'] = 'Concetto senza autore';
$string['writtenby'] = 'scritto da';
$string['youarenottheauthor'] = 'Non puoi modificare questo commento perch non ne sei autore.';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/it/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['addcomment'] = 'Aggiungi commento';
$string['addentry'] = 'Aggiungi termine';
$string['addingcomment'] = 'Aggiungi un commento';
$string['aliases'] = 'Alias (parole alternative)';
$string['allcategories'] = 'Tutte le Categorie';
$string['allentries'] = 'TUTTI';
$string['allowcomments'] = 'Permetti commenti ai termini';
$string['allowduplicatedentries'] = 'Termini duplicati permessi';
$string['allowratings'] = 'Permetti che le definizioni siano valutate?';
$string['answer'] = 'Risposta';
$string['approve'] = 'Approva';
$string['areyousuredelete'] = 'Sei sicuro di voler rimuovere questo termine?';
$string['areyousuredeletecomment'] = 'Sei sicuro di voler cancellare questo commento?';
$string['areyousureexport'] = 'Sei sicuro di voler esportare questo termine in';
$string['ascending'] = '(crescente)';
$string['attachment'] = 'Allegato';
$string['authorview'] = 'Ordina per Autore';
$string['back'] = 'Indietro';
$string['cantinsertcat'] = 'Non si pu inserire la categoria';
$string['cantinsertrec'] = 'Non si pu inserire il record';
$string['cantinsertrel'] = 'Non si pu inserire la relazione categoria-termine';
$string['casesensitive'] = 'Termine sensibile alla forma maiuscola/minuscola';
$string['categories'] = 'Categorie';
$string['category'] = 'Categoria';
$string['categorydeleted'] = 'Categoria cancellata';
$string['categoryview'] = 'Ordina per Categoria';
$string['cnfallowcomments'] = 'Definsci se un glossario pu accetttare commenti sui termini ';
$string['cnfallowdupentries'] = 'Definisci se un glossario permette la duplicazione di termini';
$string['cnfapprovalstatus'] = 'Definisci lo stato di approvazione di base per un termine aggiunto da uno studente';
$string['cnfcasesensitive'] = 'Definisci se un termine, quando  collegato,  sensibile alla forma maiuscola/minuscola';
$string['cnfdefaulthook'] = 'Seleziona la selezione standard da mostrare quando si accede al glossario la prima volta';
$string['cnfdefaultmode'] = 'Seleziona il segmento standard da mostrare quando si accede al glossario la prima volta';
$string['cnffullmatch'] = 'Definisci se per un termine, quando  collegato, deve corrispondere la capitalizzazione del testo originale';
$string['cnflinkentry'] = 'Definisci se un termine deve essere collegato automaticamente';
$string['cnflinkglossaries'] = 'Definisci se un glossario deve essere collegato automaticamente';
$string['cnfrelatedview'] = 'Seleziona il formato di visualizzazione che deve essere utilizzato per il collegamento automatico e la vista dei termini.';
$string['cnfshowgroup'] = 'Specifica la separazione dei gruppi deve essere mostrata o no.';
$string['cnfsortkey'] = 'Seleziona la chiave di ordinamento standard';
$string['cnfsortorder'] = 'Seleziona il senso di ordinamento standard';
$string['cnfstudentcanpost'] = 'Definisci se lo studente  pu inserire termini o no';
$string['comment'] = 'Commento';
$string['commentdeleted'] = 'Il commento  stato cancellato';
$string['comments'] = 'Commenti';
$string['commentson'] = 'Commenti su';
$string['commentupdated'] = 'Il commento  stato aggiornato';
$string['concept'] = 'Concetto';
$string['concepts'] = 'Concetti';
$string['configenablerssfeeds'] = 'Questa impostazione abilita l\'utilizzo degli RSS per tutti i glossari. E\' comunque necessario abilitarli manualmente nelle impostazioni di ogni glossario.';
$string['currentglossary'] = 'Glossario corrente';
$string['dateview'] = 'Ordina per Data';
$string['defaultapproval'] = 'Stato di approvazione standard';
$string['definition'] = 'Definizione';
$string['definitions'] = 'Definizioni';
$string['deleteentry'] = 'Cancella termine';
$string['deletingcomment'] = 'Cancellazione commento';
$string['deletingnoneemptycategory'] = 'Se una categoria non vuota viene cancellata, le relazioni con i suoi termini saranno cancellate. Se vuoi cancellare i termini, dovrai farlo manualmente.';
$string['descending'] = '(decrescente)';
$string['destination'] = 'Destinazione';
$string['displayformat'] = 'Formato di visualizzazione';
$string['displayformatcontinuous'] = 'Continuo senza autore';
$string['displayformatdictionary'] = 'Semplice, stile dizionario';
$string['displayformatencyclopedia'] = 'Enciclopedia';
$string['displayformatentrylist'] = 'Elenco termini';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Completo con autore';
$string['displayformatfullwithoutauthor'] = 'Completo senza autore';
$string['displayformats'] = 'Formati di visualizzazione';
$string['displayformatssetup'] = 'Impostazione del formato di visualizzazione';
$string['duplicateentry'] = 'Termine duplicato';
$string['editalways'] = 'Modifica sempre';
$string['editcategories'] = 'Modifica categorie';
$string['editentry'] = 'Modifica termine';
$string['editingcomment'] = 'Modifica commento';
$string['entbypage'] = 'Termini mostrati per pagina';
$string['entries'] = 'Termini';
$string['entrieswithoutcategory'] = 'Termini senza categorie';
$string['entry'] = 'Termine';
$string['entryalreadyexist'] = 'Il termine esiste gi';
$string['entryapproved'] = 'Questo termine  stato approvato';
$string['entrydeleted'] = 'Termine cancellato.';
$string['entryexported'] = 'Termine esportato correttamente.';
$string['entryishidden'] = '(questo termine  attualmente nascosto)';
$string['entryleveldefaultsettings'] = 'Impostazione del livello di ingresso standard';
$string['entrysaved'] = 'Questo termine  stato salvato';
$string['entryupdated'] = 'Questo termine  stato aggiornato';
$string['entryusedynalink'] = 'Collegare il termine automaticamente';
$string['explainaddentry'] = 'Aggiungi un nuovo termine al glossario corrente.<br />Concetto e definizione sono campi necessari.';
$string['explainall'] = '<b>TUTTI</b> mostrer tutti i termini in una pagina.';
$string['explainalphabet'] = 'Seleziona la lettera che vuoi vedere.<br><br>';
$string['explainexport'] = 'Un file  stato creato.<br />Scaricalo e mettilo al sicuro. Lo potrai importare quando vorrai in questo o in un altro corso.';
$string['explainimport'] = 'Devi specificare il file da importare e definire il criterio per elaborarlo. <br />Sottoponi la tua richiesta ';
$string['explainspecial'] = '<b>Speciali</b> mostrer tutti i termini che non iniziano con una lettera.';
$string['exportedentry'] = 'Termine esportato';
$string['exportedfile'] = 'File esportato';
$string['exportentries'] = 'Esporta termini';
$string['exportglossary'] = 'Esporta glossario';
$string['exporttomainglossary'] = 'Esporta nel glossario generale';
$string['filetoimport'] = 'File da importare';
$string['fillfields'] = 'Concetto e definizione sono campi necessari.';
$string['filtername'] = 'Auto-collegamento al glossario';
$string['fullmatch'] = 'Non collegare la parola quando  compresa in un altro termine';
$string['globalglossary'] = 'Glossario globale';
$string['glossaryleveldefaultsettings'] = 'Impostazione del livello dei glossari standard';
$string['glossarytype'] = 'Tipo di Glossario';
$string['glosssaryexported'] = 'Glossario esportato';
$string['importcategories'] = 'Importa categorie';
$string['importedcategories'] = 'Categorie importate';
$string['importedentries'] = 'Termini importati';
$string['importentries'] = 'Importa termini';
$string['isglobal'] = 'Questo glossario  globale?';
$string['linkcategory'] = 'Collega automaticamente questa categoria';
$string['mainglossary'] = 'Glossario principale';
$string['maxtimehaspassed'] = 'Spiacente, ma il tempo massimo per modificare questo commento ($a)  terminato!';
$string['modulename'] = 'Glossario';
$string['modulenameplural'] = 'Glossari';
$string['newentries'] = 'Nuovi termini del glossario';
$string['newglossary'] = 'Nuovo glossario';
$string['newglossarycreated'] = 'Creato nuovo glossario.';
$string['newglossaryentries'] = 'Nuovo termine del glossario:';
$string['nocomment'] = 'Nessun commento trovato';
$string['nocomments'] = '(Nessun commento trovato per questo termine)';
$string['noconceptfound'] = 'Nessun concetto o definizione trovato.';
$string['noentries'] = 'Nessun termine trovato in questa sessione';
$string['noentry'] = 'Nessun termine trovato.';
$string['notcategorised'] = 'Non diviso in categorie';
$string['numberofentries'] = 'Numeto di termini';
$string['onebyline'] = '(uno per riga)';
$string['printerfriendly'] = 'Versione stampabile';
$string['question'] = 'Domanda';
$string['rate'] = 'Voto';
$string['rating'] = 'Valutazione';
$string['ratingeveryone'] = 'Tutti possono valutare i termini';
$string['ratingno'] = 'Nessuna valutazione';
$string['ratingonlyteachers'] = 'Solo $a pu valutare i termini';
$string['ratings'] = 'Valutazioni';
$string['ratingssaved'] = 'Valutazioni salvate';
$string['ratingsuse'] = 'Utilizza le valutazioni';
$string['ratingtime'] = 'Restringi la valutazione ai termini tra queste date:';
$string['rejectedentries'] = 'Termini rigettati';
$string['rejectionrpt'] = 'Rapporto rigettazione';
$string['rsssubscriberss'] = 'Mostra gli RSS per \'$a\' concetti.';
$string['searchindefinition'] = 'Cerco tra i concetti e le definizioni?';
$string['secondaryglossary'] = 'Glossario secondario';
$string['sendinratings'] = 'Spediscilo nella mia ultima valutazione';
$string['showall'] = 'Mostra link \'TUTTI\'';
$string['showalphabet'] = 'Mostra alfabeto';
$string['showspecial'] = 'Mostra link \'Speciali\'';
$string['sortby'] = 'Ordina per ';
$string['sortbycreation'] = 'Per data di creazione';
$string['sortbylastupdate'] = 'Per ultimo aggiornamento';
$string['sortchronogically'] = 'Ordina cronologicamente';
$string['special'] = 'Speciali';
$string['standardview'] = 'Vista Standard';
$string['studentcanpost'] = 'Gli studenti posso aggiungere termini';
$string['totalentries'] = 'Totale termini';
$string['usedynalink'] = 'Collega automaticamente i termini del glossario';
$string['waitingapproval'] = 'Attende approvazione';
$string['warningstudentcapost'] = '(Questo viene applicato solo se il glossario non  quello generale)';
$string['withauthor'] = 'Concetto con autore';
$string['withoutauthor'] = 'Concetto senza autore';
$string['writtenby'] = 'scritto da';
$string['youarenottheauthor'] = 'Non puoi modificare questo commento perch non ne sei autore.';

?>
